@@ -73,7 +73,7 @@ class ChessDaskCluster:
         for task_future in task_futures:
             control_list_for_game.append(task_future.result())
         game_data = ChessDaskCluster.get_game_data(control_list_for_game)
-        game_data["filename"] = "Game" + str(game_no)
+        game_data["filename"] = str(game_no) + " " + game.headers["Event"]
         return game_data
 
     def __init__(self):
